==> opentelemetry-api-0.4.0-sources.jar: io/opentelemetry/trace/TracerProvider.java <==
/*
 * Copyright 2019, OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.opentelemetry.trace;

import javax.annotation.concurrent.ThreadSafe;

/**
 * A registry for creating named {@link Tracer}s. Although the class is provided at runtime via
 * {@link io.opentelemetry.trace.spi.TraceProvider}, the name <i>Provider</i> is for consistency
 * with other languages.
 *
 * @see io.opentelemetry.OpenTelemetry
 * @see io.opentelemetry.trace.Tracer
 * @since 0.1.0
 */
@ThreadSafe
public interface TracerProvider {

  /**
   * Gets or creates a named tracer instance.
   *
   * @param instrumentationName The name of the instrumentation library, not the name of the
   *     instrument*ed* library (e.g., "io.opentelemetry.contrib.mongodb"). Must not be null.
   * @return a tracer instance.
   * @since 0.1.0
   */
  Tracer get(String instrumentationName);

  /**
   * Gets or creates a named and versioned tracer instance.
   *
   * @param instrumentationName The name of the instrumentation library, not the name of the
   *     instrument*ed* library (e.g., "io.opentelemetry.contrib.mongodb"). Must not be null.
   * @param instrumentationVersion The version of the instrumentation library (e.g.,
   *     "semver:1.0.0").
   * @return a tracer instance.
   * @since 0.1.0
   */
  Tracer get(String instrumentationName, String instrumentationVersion);
}

==> opentelemetry-api-0.6.0-sources.jar: io/opentelemetry/trace/TracerProvider.java <==
/*
 * Copyright 2019, OpenTelemetry Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.opentelemetry.trace;

import io.opentelemetry.trace.spi.TracerProviderFactory;
import javax.annotation.concurrent.ThreadSafe;

/**
 * A registry for creating named {@link Tracer}s. Although the class is provided at runtime via
 * {@link TracerProviderFactory}, the name <i>Provider</i> is for consistency with other languages.
 *
 * @see io.opentelemetry.OpenTelemetry
 * @see io.opentelemetry.trace.Tracer
 * @since 0.1.0
 */
@ThreadSafe
public interface TracerProvider {

  /**
   * Gets or creates a named tracer instance.
   *
   * @param instrumentationName The name of the instrumentation library, not the name of the
   *     instrument*ed* library (e.g., "io.opentelemetry.contrib.mongodb"). Must not be null.
   * @return a tracer instance.
   * @since 0.1.0
   */
  Tracer get(String instrumentationName);

  /**
   * Gets or creates a named and versioned tracer instance.
   *
   * @param instrumentationName The name of the instrumentation library, not the name of the
   *     instrument*ed* library (e.g., "io.opentelemetry.contrib.mongodb"). Must not be null.
   * @param instrumentationVersion The version of the instrumentation library (e.g.,
   *     "semver:1.0.0").
   * @return a tracer instance.
   * @since 0.1.0
   */
  Tracer get(String instrumentationName, String instrumentationVersion);
}
